@@ -1,10 +1,10 @@
 context("Age Precision and Bias MESSAGES")
-data(WhitefishLC)
 
 test_that("ageBias() messages",{
   expect_error(ageBias(otolithC+scaleC~finrayC,data=WhitefishLC),
                "more than one variable on the LHS")
-  expect_error(ageBias(otolithC~scaleC+finrayC,data=WhitefishLC),"must have only one RHS")
+  expect_error(ageBias(otolithC~scaleC+finrayC,data=WhitefishLC),
+               "must have only one RHS")
   
   suppressWarnings(ab1 <- ageBias(scaleC~otolithC,data=WhitefishLC))
   expect_error(summary(ab1,what="derek"),"should be one of")
@@ -14,6 +14,10 @@ test_that("ageBias() messages",{
 })
 
 test_that("agePrecision() messages",{
+  expect_error(agePrecision(~otolithC,data=WhitefishLC),
+               "compare at least two sets of ages")
+  expect_error(agePrecision(~otolithC+as.character(scaleC),data=WhitefishLC),
+               "must be numeric")
   ap1 <- agePrecision(~otolithC+scaleC,data=WhitefishLC)
   expect_error(summary(ap1,what="agreement"),"should be one of")
   expect_error(summary(ap1,what="absolute",trunc.diff=0),"must be positive")
