@@ -5,7 +5,7 @@ test_that("removal with 'CarleStrub' matches Carle-Strub (1978) examples",{
   expect_equal(round(tmp["No","Estimate"],0),91)
   expect_equal(round(tmp["No","Std. Error"],1),9.7)
   expect_equal(round(tmp["p","Estimate"],3),0.444)
-  
+
   tmp <- summary(removal(c(5,7,8)))
   expect_equal(round(tmp["No","Estimate"],0),44)
   expect_equal(round(tmp["p","Estimate"],3),0.174)
@@ -17,7 +17,7 @@ test_that("removal with 'CarleStrub' matches Cowx (1983) page 77",{
   expect_equal(round(tmp["p","Estimate"],3),0.250)
   # SE does not match
   #expect_equal(round(tmp["No","Std. Error"],1),23.62)
-  
+
   tmp <- summary(removal(c(8,23,17,8,6)))
   expect_equal(round(tmp["No","Estimate"],0),95)
   expect_equal(round(tmp["p","Estimate"],3),0.187)
@@ -25,8 +25,8 @@ test_that("removal with 'CarleStrub' matches Cowx (1983) page 77",{
 
 test_that("removal with 'CarleStrub' match results from Jones & Stockwell (1995)",{
   if (require(FSAdata)) {
-    data(JonesStockwell)
-    # isolate captures and Carel-Strub estimates ... for non-rejected estimates
+    data(JonesStockwell,package="FSAdata")
+    # isolate captures and Carle-Strub estimates ... for non-rejected estimates
     JS.caps <- JonesStockwell[!JonesStockwell$rejected,4:6]
     JS.cs <- JonesStockwell[!JonesStockwell$rejected,7]
     # compute Carle-Strub estimates for all data in JS.caps
@@ -67,7 +67,7 @@ test_that("removal with 'RobsonRegier2' matches Cowx (1983) page 75",{
 
 test_that("removal with 'Moran' matches Schnute (1983)",{
   if (require(FSAdata)) {
-    data(BrookTroutNEWP1)
+    data(BrookTroutNEWP1,package="FSAdata")
     Ns <- ps <- LHs <- NLCI <- NUCI <- numeric(nrow(BrookTroutNEWP1))
     for (i in seq_len(nrow(BrookTroutNEWP1))) {
       tmp <- removal(as.numeric(BrookTroutNEWP1[i,c("first","second","third","fourth")]),method="Moran")
@@ -79,20 +79,22 @@ test_that("removal with 'Moran' matches Schnute (1983)",{
       NUCI[i] <- tmp[2]
     }
     ## check point estimates
-    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),Ns,ps,LHs,BrookTroutNEWP1[,c("Moran.N","Moran.p","Moran.LH")])
+    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),Ns,ps,LHs,
+                 BrookTroutNEWP1[,c("Moran.N","Moran.p","Moran.LH")])
     ## perfect matches
     expect_equal(tmp[,"Ns"],BrookTroutNEWP1$Moran.N[])
     expect_equal(tmp[,"ps"],BrookTroutNEWP1$Moran.p[])
     expect_equal(tmp[,"LHs"],BrookTroutNEWP1$Moran.LH[])
     ## Check CIs (off by no more than 0.1 in a small handful of the UCIs)
-    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),NLCI,NUCI,BrookTroutNEWP1[,c("Moran.NLCI","Moran.NUCI")])
+    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),NLCI,NUCI,
+                 BrookTroutNEWP1[,c("Moran.NLCI","Moran.NUCI")])
     expect_true(all(abs(tmp[,2:3]-tmp[,4:5])<=0.1001))
   }
 })
 
 test_that("removal with 'Schnute' matches Schnute (1983)",{
   if (require(FSAdata)) {
-    data(BrookTroutNEWP1)
+    data(BrookTroutNEWP1,package="FSAdata")
     Ns <- p1s <- ps <- LHs <- NLCI <- NUCI <- numeric(nrow(BrookTroutNEWP1))
     for (i in seq_len(nrow(BrookTroutNEWP1))) {
       tmp <- removal(as.numeric(BrookTroutNEWP1[i,c("first","second","third","fourth")]),method="Schnute")
@@ -105,14 +107,31 @@ test_that("removal with 'Schnute' matches Schnute (1983)",{
       NUCI[i] <- tmp[2]
     }
     ## check point estimates
-    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),Ns,p1s,ps,LHs,BrookTroutNEWP1[,c("Schnute.N","Schnute.p1","Schnute.p","Schnute.LH")])
+    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),Ns,p1s,ps,LHs,
+                 BrookTroutNEWP1[,c("Schnute.N","Schnute.p1","Schnute.p","Schnute.LH")])
     ## perfect matches except sample 5 N is off by 0.1
     expect_equal(tmp[-5,"Ns"],BrookTroutNEWP1$Schnute.N[-5])
     expect_equal(tmp[,"p1s"],BrookTroutNEWP1$Schnute.p1[])
     expect_equal(tmp[,"ps"],BrookTroutNEWP1$Schnute.p[])
     expect_equal(tmp[,"LHs"],BrookTroutNEWP1$Schnute.LH[])
     ## Check CIs (off by no more than 0.1)
-    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),NLCI,NUCI,BrookTroutNEWP1[,c("Schnute.NLCI","Schnute.NUCI")])
+    tmp <- cbind(sample=seq_len(nrow(BrookTroutNEWP1)),NLCI,NUCI,
+                 BrookTroutNEWP1[,c("Schnute.NLCI","Schnute.NUCI")])
     expect_true(all(abs(tmp[,2:3]-tmp[,4:5])<=0.1001,na.rm=TRUE))
   }
+
+})
+test_that("removal with 'Burnham' match results from (Van Deventer 1989) page 13",{
+  tmp <- removal(c(124,61,35,14),method="Burnham",CIMicroFish=TRUE)
+  ## check point estimates
+  tmp2 <- summary(tmp)
+  expect_equal(round(tmp2["No","Estimate"],0),249)
+  expect_equal(round(tmp2["No","Std. Error"],3),6.164)
+  expect_equal(round(tmp2["p","Estimate"],3),0.501)
+  expect_equal(round(tmp2["p","Std. Error"],3),0.035)
+  ## check CIs
+  tmp2 <- confint(tmp)
+  expect_equal(round(as.numeric(tmp2["No",]),3),c(237,261))
+  expect_equal(round(as.numeric(tmp2["p",]),3),c(0.432,0.570))
+  
 })
